package
Version:
v0.2.3
Opens a new window with list of versions in this module.
Published: Mar 28, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Length struct {
Min, Max int
}
Length 长度规则
type Option func(*options)
Option 是验证器选项函数
type Pattern struct {
Regex string
}
Pattern 模式规则
type Range struct {
Min, Max float64
}
Range 范围规则
type Rule interface {
Validate(value interface{}) error
}
Rule 是验证规则接口
Source Files
¶
Click to show internal directories.
Click to hide internal directories.